/* libmondo-mountlist.h
 * $Id: libmondo-mountlist.h 2394 2009-09-12 00:53:02Z bruno $
 */


char *evaluate_mountlist(struct mountlist_itself *mountlist);
int find_device_in_mountlist(struct mountlist_itself *mountlist,
							 char *device);
int make_list_of_drives_in_mountlist(struct mountlist_itself *,
									 struct list_of_disks *);
long long size_of_specific_device_in_mountlist(struct mountlist_itself
											   *mountlist, char *device);


int load_mountlist(struct mountlist_itself *mountlist, char *fname);
void sort_mountlist_by_device(struct mountlist_itself *mountlist);
int save_mountlist_to_disk(struct mountlist_itself *mountlist,
						   char *fname);
void sort_mountlist_by_mountpoint(struct mountlist_itself *mountlist,
								  bool reverse);
void sort_mountlist_by_device(struct mountlist_itself *mountlist);
void swap_mountlist_entries(struct mountlist_itself *mountlist, int a,
							int b);
